#!/bin/bash

set -ex

################
# Usage: controller.sh <os> <version> <basepath>
# The controller script does all of the jar compilation
# and setup needed to build packages for <os>
# The os string should be one of el, sles, debian, ubuntu,
# or fedora
# The version should be the numerical OS version for el,
# sles, and fedora and the codename for debian/ubuntu.
# The resulting artifacts will be stored in <basepath>
################
build_os=$1
build_ver=$2
basepath=$3

if [ ! -d "$basepath" ]; then
  mkdir -p $basepath
fi
if [ ! -d "$basepath/base" ]; then
        DESTDIR="$basepath/base" bash install.sh install_redhat
fi
if [ ! -d "$basepath/systemd_el" ]; then
        cp -r "$basepath/base" "$basepath/systemd_el"
        DESTDIR="$basepath/systemd_el" bash install.sh systemd_redhat
fi
if [ ! -d "$basepath/old_el" ]; then
        cp -r "$basepath/base" "$basepath/old_el"
        DESTDIR="$basepath/old_el" bash install.sh sysv_init_redhat
fi
if [ ! -d "$basepath/old_sles" ]; then
        cp -r "$basepath/base" "$basepath/old_sles"
        DESTDIR="$basepath/old_sles" bash install.sh sysv_init_suse
fi


# things are only different if we have docs, deb docs get
# installed in an unversioned folder but rpm docs get installed
# in a versioned folder.
if [ -d ext/docs ]; then
        if [ ! -d "$basepath/base_deb" ]; then
                DESTDIR="$basepath/base_deb" bash install.sh install_deb
                if [ ! -d "$basepath/systemd_deb" ]; then
                        cp -r "$basepath/base_deb" "$basepath/systemd_deb"
                        DESTDIR="$basepath/systemd_deb" bash install.sh systemd_deb
                fi
                if [ ! -d "$basepath/sysvinit_deb" ]; then
                        cp -r "$basepath/base_deb" "$basepath/sysvinit_deb"
                        DESTDIR="$basepath/sysvinit_deb" bash install.sh sysv_init_deb
                fi
        fi
else
        if [ ! -d "$basepath/systemd_deb" ]; then
                cp -r "$basepath/base" "$basepath/systemd_deb"
                DESTDIR="$basepath/systemd_deb" bash install.sh systemd_deb
        fi
        if [ ! -d "$basepath/sysvinit_deb" ]; then
                cp -r "$basepath/base" "$basepath/sysvinit_deb"
                DESTDIR="$basepath/sysvinit_deb" bash install.sh sysv_init_deb
        fi
fi

os=$build_os
if [ "$os" = "debian" ]; then
        os_dist=$build_ver
else
        os_version=$build_ver
fi

case $os in
        # there's no differences in packaging for deb vs ubuntu
        # if that changes we'll need to fix this
        debian|ubuntu)
                if [ "$os_dist" = 'trusty' ]; then
                        dir="$basepath/sysvinit_deb"
                else
                        dir="$basepath/systemd_deb"
                fi
                ;;
        el)
                if [ "$os_version" -gt '6' ]; then
                        dir="$basepath/systemd_el"
                else
                        dir="$basepath/old_el"
                fi
                ;;
        sles)
                if [ "$os_version" -gt '11' ]; then
                        dir="$basepath/systemd_el"
                else
                        dir="$basepath/old_sles"
                fi
                ;;
        *)
                echo "I have no idea what I'm doing with $os, teach me?" >&2
                exit 1
                ;;
esac

# bash will eat your spaces, so let's array. see http://mywiki.wooledge.org/BashFAQ/050 for more fun.
params=("--user" "puppetdb" "--group" "puppetdb" "--chdir" "$dir" "--realname" "puppetdb" "--operating-system" "$os" "--name" "puppetdb" "--package-version" "5.2.7" "--release" "1")
if [ -n "$os_version" ]; then params+=("--os-version" "$os_version"); fi
if [ -n "$os_dist" ]; then params+=("--dist" "$os_dist"); fi

params+=('--description' 'Puppet Labs puppetdb. Contains: Puppet-integrated catalog and fact storage (puppetlabs/puppetdb 5.2.7,puppetlabs/trapperkeeper-webserver-jetty9 2.3.1,org.clojure/clojure 1.8.0,org.clojure/core.async 0.2.391,org.clojure/core.match 0.3.0-alpha4,org.clojure/core.memoize 0.5.9,org.clojure/java.jdbc 0.6.2-alpha3,org.clojure/tools.macro 0.1.5,org.clojure/math.combinatorics 0.1.1,org.clojure/math.numeric-tower 0.0.4,org.clojure/tools.logging 0.3.1,puppetlabs/comidi 0.3.1,puppetlabs/dujour-version-check 0.2.1,puppetlabs/http-client 0.9.0,puppetlabs/i18n 0.8.0,puppetlabs/kitchensink 2.5.1,puppetlabs/stockpile 0.0.4,puppetlabs/tools.namespace 0.2.4.1,puppetlabs/trapperkeeper 1.5.3,puppetlabs/trapperkeeper-metrics 1.1.0,puppetlabs/trapperkeeper-status 0.7.1,cheshire/cheshire 5.8.0,clj-stacktrace/clj-stacktrace 0.2.8,clj-time/clj-time 0.11.0,com.rpl/specter 0.5.7,com.taoensso/nippy 2.10.0,digest/digest 1.4.3,fast-zip-visit/fast-zip-visit 1.0.2,instaparse/instaparse 1.4.1,me.raynes/fs 1.4.6,metrics-clojure/metrics-clojure 2.6.1,prismatic/schema 1.1.2,robert/hooke 1.3.0,slingshot/slingshot 0.12.2,trptcolin/versioneer 0.2.0,org.apache.commons/commons-lang3 3.4,overtone/at-at 1.2.0,com.zaxxer/HikariCP 2.6.1,honeysql/honeysql 0.6.3,org.postgresql/postgresql 9.4.1208.jre7,org.apache.activemq/activemq-broker 5.13.2,org.apache.activemq/activemq-kahadb-store 5.13.2,org.apache.activemq/activemq-pool 5.13.2,org.slf4j/jcl-over-slf4j 1.7.14,bidi/bidi 2.0.12,clj-http/clj-http 2.0.1,com.novemberain/pantomime 2.1.0,compojure/compojure 1.5.0,org.apache.commons/commons-compress 1.10,ring/ring-core 1.4.0,puppetlabs/puppetdb 5.2.7)')

DESTDIR="$basepath/termini" bash install.sh termini
params+=('--build-termini')
params+=('--termini-chdir' "$basepath/termini")
termini_description='Termini for puppetdb. Contains terminus for:'

termini_description+='puppetdb (version 5.2.7)'

params+=('--termini-description' "$termini_description")







if [[ "$os" = 'el' || "$os" = 'sles' || "$os" = 'fedora' ]]; then
        # pull in rpm dependencies
                        params+=("--additional-dependency")
                params+=("puppet-agent >= 4.99.0")
                # get rpm install trigger scripts
                # get rpm upgrade trigger scripts
                : # Need something in case there are no additional dependencies
else
        # if we aren't an rpm, pull in deb dependencies
                        params+=("--additional-dependency")
                params+=("puppet-agent (>= 4.99.0)")
                                        : # Need something in case there are no additional dependencies
fi


ruby $PWD/ext/fpm.rb "${params[@]}"
